@@ -6,6 +6,7 @@ import click
 from yojenkins.__main__ import build
 from yojenkins.cli import cli_build, cli_decorators
 from yojenkins.cli.cli_utility import set_debug_log_level
+from yojenkins.utility.utility import translate_kwargs
 
 
 @build.command(short_help='\tBuild information')
@@ -17,10 +18,11 @@ from yojenkins.cli.cli_utility import set_debug_log_level
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=bool, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def info(ctx, debug, pretty, yaml, xml, toml, profile, job, number, url, latest):
+def info(ctx, debug, **kwargs):
+    """Build information"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.info(pretty, yaml, xml, toml, profile, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.info(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -33,10 +35,11 @@ def info(ctx, debug, pretty, yaml, xml, toml, profile, job, number, url, latest)
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=bool, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def status(ctx, debug, profile, job, number, url, latest):
+def status(ctx, debug, **kwargs):
+    """Build status text/label"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.status(profile, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.status(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
     # FIXME: Showing running for job, seems not to have picked the right build ... when url to job is used!
@@ -50,10 +53,11 @@ def status(ctx, debug, profile, job, number, url, latest):
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=str, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def abort(ctx, debug, profile, job, number, url, latest):
+def abort(ctx, debug, **kwargs):
+    """Abort build"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.abort(profile, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.abort(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -66,11 +70,12 @@ def abort(ctx, debug, profile, job, number, url, latest):
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=str, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def delete(ctx, debug, profile, job, number, url, latest):
+def delete(ctx, debug, **kwargs):
+    """Delete build"""
     # TODO: Pass a list of build numbers
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.delete(profile, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.delete(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -85,10 +90,11 @@ def delete(ctx, debug, profile, job, number, url, latest):
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=str, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def stages(ctx, debug, pretty, yaml, xml, toml, profile, list, job, number, url, latest):
+def stages(ctx, debug, **kwargs):
+    """Get build stages"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.stages(pretty, yaml, xml, toml, profile, list, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.stages(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -114,10 +120,11 @@ def stages(ctx, debug, pretty, yaml, xml, toml, profile, list, job, number, url,
               is_flag=True,
               help='Follow/Stream the logs as they are generated')
 @click.pass_context
-def logs(ctx, debug, profile, job, number, url, latest, tail, download_dir, follow):
+def logs(ctx, debug, **kwargs):
+    """Get build logs"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.logs(profile, job, number, url, latest, tail, download_dir, follow)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.logs(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -130,11 +137,12 @@ def logs(ctx, debug, profile, job, number, url, latest, tail, download_dir, foll
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=str, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def browser(ctx, debug, profile, job, number, url, latest):
+def browser(ctx, debug, **kwargs):
+    """Open build in web browser"""
     # TODO: Pass a list of build numbers
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.browser(profile, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.browser(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -148,14 +156,33 @@ def browser(ctx, debug, profile, job, number, url, latest):
 @click.option('--latest', type=str, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.option('-s', '--sound', type=bool, required=False, is_flag=True, help='Enable sound effects')
 @click.pass_context
-def monitor(ctx, debug, profile, job, number, url, latest, sound):
+def monitor(ctx, debug, **kwargs):
+    """Start monitor UI"""
     # TODO: Pass a list of build numbers
     set_debug_log_level(debug)
-    if job or url:
-        cli_build.monitor(profile, job, number, url, latest, sound)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.monitor(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
 
-# TODO:
-#   - Build test report
+@build.command(short_help='\tGet build parameters')
+@cli_decorators.debug
+@cli_decorators.format_output
+@cli_decorators.profile
+@cli_decorators.list
+@click.argument('job', nargs=1, type=str, required=False)
+@click.option('-n', '--number', type=int, required=False, help='Build number')
+@click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
+@click.option('--latest', type=str, required=False, is_flag=True, help='Latest build (Replaces --number)')
+@click.pass_context
+def parameters(ctx, debug, **kwargs):
+    """Get build parameters
+
+    Build parameters are the parameters that were used to start the build.
+    """
+    set_debug_log_level(debug)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_build.parameters(**translate_kwargs(kwargs))
+    else:
+        click.echo(ctx.get_help())
