@@ -6,6 +6,7 @@ import click
 from yojenkins.__main__ import step
 from yojenkins.cli import cli_decorators, cli_step
 from yojenkins.cli.cli_utility import set_debug_log_level
+from yojenkins.utility.utility import translate_kwargs
 
 
 @step.command(short_help='\tStep information')
@@ -13,8 +14,7 @@ from yojenkins.cli.cli_utility import set_debug_log_level
 @cli_decorators.format_output
 @cli_decorators.profile
 @click.argument('url', nargs=1, type=str, required=True)
-@click.pass_context
-def info(debug, pretty, yaml, xml, toml, profile, url):
+def info(debug, **kwargs):
     """Step information"""
     set_debug_log_level(debug)
-    cli_step.info(pretty, yaml, xml, toml, profile, url)
+    cli_step.info(**translate_kwargs(kwargs))
