@@ -30,6 +30,9 @@ KWARG_TRANSLATE_MAP = {
     'yaml': 'opt_yaml',
     'xml': 'opt_xml',
     'toml': 'opt_toml',
+    'list': 'opt_list',
+    'json': 'opt_json',
+    'id': 'opt_id',
 }
 
 
@@ -918,10 +921,10 @@ def write_xml_to_file(xml_content: str,
 
     Args:
         xml_content : XML content to be written
-        filepath : Filepath to write the content to
-        opt_json : Write the content as JSON
-        opt_yaml : Write the content as YAML
-        opt_toml : Write the content as TOML
+        filepath    : Filepath to write the content to
+        opt_json    : Write the content as JSON
+        opt_yaml    : Write the content as YAML
+        opt_toml    : Write the content as TOML
 
     Returns:
         True if successful
